#ifndef SETTINGSWINDOW_H
#define SETTINGSWINDOW_H

#include <QDialog>
#include <QSettings>
#include "controls/dialogwindow.h"
namespace Ui {
    class SettingsWindow;
}

class SettingsWindow : public DialogWindow
{
    Q_OBJECT

public:
    explicit SettingsWindow(QWidget *parent = 0);
    ~SettingsWindow();

private:
    Ui::SettingsWindow *ui;

    QFont m_Font;
    QSettings* m_Settings;
    void ShowData();

private slots:
    void SaveSlot();
    void BackgroundSlot();
    void ColorSlot();
    void FontSlot();
    void CssSlot(bool);
};

#endif // SETTINGSWINDOW_H
